$set 3 #Configmenu

$ #ConfigOptions
# 
$ #FocusModel
#  
$ #WindowPlacement
#   
$ #ImageDithering
# Image Dithering
$ #OpaqueMove
#    
$ #FullMax
#  
$ #FocusNew
#   
$ #FocusLast
#       
$ #ClickToFocus
#   
$ #SloppyFocus
# Sloppy 
$ #AutoRaise
#  
$ #SmartRows
#   ()
$ #SmartCols
#   ()
$ #Cascade
#  
$ #LeftRight
#    
$ #RightLeft
#    
$ #TopBottom
#    
$ #BottomTop
#    
$ #Tabs
#  
$ #Icons
#  
$ #TabPlacement
#   
$ #TabRotateVertical
#   
$ #SemiSloppyFocus
#  Sloppy 
$ #MaxOverSlit
#   Slit -
$ #SloppyWindowGrouping
# Sloppy   
$ #WorkspaceWarping
# Workspace Warping
